@@ -16,6 +16,7 @@ from .exceptions import AAFPropertyError
 from .auid import AUID
 
 import datetime
+import logging
 
 from struct import (unpack, pack)
 from .utils import register_class, decode_utf16le, encode_utf16le, encode_utf16_array, encode_auid_array
@@ -391,6 +392,7 @@ class TypeDefVarArray(TypeDef):
     def element_typedef(self):
         if PID_VAR_TYPE in self.property_entries:
             return self.root.metadict.lookup_typedef(self.property_entries[PID_VAR_TYPE].ref)
+
     @property
     def ref_classdef(self):
         typedef = self.element_typedef
@@ -562,6 +564,14 @@ class TypeDefRecord(TypeDef):
         self._fields = None
         return self
 
+    @property
+    def member_names(self):
+        return list(iter_utf16_array(self['MemberNames'].data))
+
+    @property
+    def member_types(self):
+        return self['MemberTypes']
+
     @property
     def fields(self):
         if self._fields:
@@ -605,24 +615,39 @@ class TypeDefRecord(TypeDef):
             result[key] = typedef.decode(data[start:end])
             start = end
 
+        # NOTE: If datetime helpers raise exception record is returned as a dict
 
         # TimeStruct
         if self.auid == TIMESTRUCT_AUID:
-            t = datetime.time(result['hour'],
-                              result['minute'],
-                              result['second'],
-                              result['fraction'])
-            return t
+            try:
+                t = datetime.time(result['hour'],
+                                result['minute'],
+                                result['second'],
+                                result['fraction'])
+                return t
+            except:
+                logging.warning("unable to decode time: {}".format(result))
 
         # DateStruct
         if self.auid == DATESTRUCT_AUID:
-            d = datetime.date(**result)
-            return d
+            # aaf sdk struct says:
+            # year   range -32,767 to +32767
+            # month  range: 1-12, inclusive
+            # day    range: 1-31, inclusive
+            try:
+                d = datetime.date(**result)
+                return d
+            except:
+                logging.warning("unable to decode date: {}".format(result))
 
         # TimeStamp
         if self.auid == TIMESTAMP_AUID:
-            d = datetime.datetime.combine(result['date'], result['time'])
-            return d
+            if isinstance(result.get('date', {}), datetime.date):
+                try:
+                    d = datetime.datetime.combine(result['date'], result['time'])
+                    return d
+                except:
+                    logging.warning("unable to decode timestamp: {}".format(result))
 
         # Rational
         if self.auid == RATIONAL_AUID:
@@ -642,8 +667,7 @@ class TypeDefRecord(TypeDef):
 
         result = b""
         # TimeStamp
-        if self.auid == TIMESTAMP_AUID:
-            assert isinstance(data, datetime.datetime)
+        if self.auid == TIMESTAMP_AUID and isinstance(data, datetime.datetime):
             f = [self.root.metadict.lookup_typedef(t) for k, t in self.fields]
             #date
             result += f[0].encode(data.date())
@@ -654,8 +678,7 @@ class TypeDefRecord(TypeDef):
 
 
         # DateStruct
-        if self.auid == DATESTRUCT_AUID:
-            assert isinstance(data, datetime.date)
+        if self.auid == DATESTRUCT_AUID and isinstance(data, datetime.date):
             d = {'year' : data.year,
                  'month' : data.month,
                  'day': data.day}
@@ -663,8 +686,7 @@ class TypeDefRecord(TypeDef):
             data = d
 
         # TimeStruct
-        if self.auid == TIMESTRUCT_AUID:
-            assert isinstance(data, datetime.time)
+        if self.auid == TIMESTRUCT_AUID and isinstance(data, datetime.time):
             t = {'hour' : data.hour,
                  'minute' : data.minute,
                  'second' : data.second,
